CalendarParameter<ValueType extends CalendarParameterValue> class
abstract
- Implementers
- AlarmTriggerRelationshipParameter
- AlternateTextRepresentationParameter
- CalendarUserTypeParameter
- CommonNameParameter
- DelegateesParameter
- DelegatorsParameter
- DirectoryEntryParameter
- FormatTypeParameter
- FreeBusyTimeTypeParameter
- GroupOrListMembershipParameter
- InlineEncodingParameter
- LanguageParameter
- ParticipationRoleParameter
- ParticipationStatusParameter
- RecurrenceIdentifierRangeParameter
- RelationshipTypeParameter
- RSVPExpectationParameter
- SentByParameter
- TimeZoneIdentifierParameter
- ValueDataTypeParameter
Constructors
- CalendarParameter(String parameterName, ValueType value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parameterName → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - value → ValueType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited