CalendarProperty<ValueType extends CalendarValue> class
abstract
- Implementers
- ActionProperty
- AttendeeProperty
- BinaryAttachmentProperty
- CalendarScaleProperty
- CategoriesProperty
- ClassificationProperty
- CommentProperty
- ContactProperty
- DateTimeCompletedProperty
- DateTimeCreatedProperty
- DateTimeDueProperty
- DateTimeEndProperty
- DateTimeStampProperty
- DateTimeStartProperty
- DateTimeTriggerProperty
- DescriptionProperty
- DurationProperty
- DurationTriggerProperty
- ExceptionDateTimesProperty
- ExceptionRuleProperty
- FreeBusyTimeProperty
- GeographicPositionProperty
- LastModifiedProperty
- LocationProperty
- MethodProperty
- OrganizerProperty
- PercentCompleteProperty
- PriorityProperty
- ProductIdentifierProperty
- RecurrenceDateTimesProperty
- RecurrenceIdProperty
- RecurrenceRuleProperty
- RelatedToProperty
- RepeatCountProperty
- RequestStatusProperty
- ResourcesProperty
- SequenceProperty
- StatusProperty
- SummaryProperty
- TimeTransparencyProperty
- TimeZoneIdentifierProperty
- TimeZoneNameProperty
- TimeZoneOffsetFromProperty
- TimeZoneOffsetToProperty
- TimeZoneUrlProperty
- UniqueIdentifierProperty
- UriAttachmentProperty
- URLProperty
- VersionProperty
Constructors
- CalendarProperty(String propertyName, ValueType value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- propertyName → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - value → ValueType
-
final
Methods
-
getParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited