toString method

  1. @override
String toString()

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  var parameters = getParameters();
  parameters.sort(
    (a, b) => a.parameterName.compareTo(b.parameterName),
  );

  final res = StringBuffer();
  res.writeAll([
    propertyName.toUpperCase(),
    ...parameters,
    ...value.getInlineParameters()
  ], ";");
  res.write(":");
  res.write(value);
  return res.toString();
}