CalendarStructuredValuePart<InnerType> class abstract

Inheritance

Constructors

CalendarStructuredValuePart(String partName, InnerType value, ValueType type)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
partName String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type ValueType
finalinherited
value → InnerType
finalinherited

Methods

getInlineParameters() List<CalendarParameter<CalendarParameterValue>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitizeToString() String
inherited
toString() String
A string representation of this object.
override
validate() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited