CalendarUserAddressValue class
RFC2445 Section 4.3.3
- Inheritance
-
- Object
- CalendarValue<
String> - CalendarUserAddressValue
- Implementers
Constructors
- CalendarUserAddressValue(String email)
-
const
- CalendarUserAddressValue.fromCrawledStringValue(String value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → ValueType
-
finalinherited
- value → String
-
finalinherited
Methods
-
getInlineParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitizeToString(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited