CalendarValue<InnerType> class abstract

Implementers

Constructors

CalendarValue(InnerType value, ValueType type)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type ValueType
final
value → InnerType
final

Methods

getInlineParameters() List<CalendarParameter<CalendarParameterValue>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitizeToString() String
toString() String
A string representation of this object.
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited