CategoriesProperty class
RFC2445 Section 4.8.1.2
- Inheritance
-
- Object
- CalendarProperty<
CalendarValueList< TextValue> > - CategoriesProperty
Constructors
-
CategoriesProperty(List<
String> values, {Locale? locale}) - CategoriesProperty.fromCrawledProperty(CrawledProperty property)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → Locale?
-
final
- propertyName → String
-
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
value
→ CalendarValueList<
TextValue> -
finalinherited
Methods
-
getParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited