DateTimeValue class

RFC2445 Section 4.3.5

Inheritance
Implementers

Constructors

DateTimeValue(DateTime value, {bool fixed = _defaultFixed, String? timeZoneIdentifier})
DateTimeValue.fromCrawledStringValue(String value, {String? timeZoneIdentifier})
factory

Properties

fixed bool
If set to true, will fix the time value to either the supplied timeZoneIdentifier or to the UTC timezone by default
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timeZoneIdentifier String?
The tzId value of a TimeZoneComponent located inside the current calendar
final
type ValueType
finalinherited
value DateTime
finalinherited

Methods

getInlineParameters() List<CalendarParameter<CalendarParameterValue>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitizeToString() String
override
toString() String
A string representation of this object.
inherited
validate() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited