DateValue class

RFC2445 Section 4.3.4

Inheritance
Implementers

Constructors

DateValue(DateTime value)
const
DateValue.fromCrawledStringValue(String value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type ValueType
finalinherited
value DateTime
finalinherited

Methods

getInlineParameters() List<CalendarParameter<CalendarParameterValue>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitizeToString() String
override
toString() String
A string representation of this object.
inherited
validate() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited