DaylightTimeZoneComponent class

Inheritance

Constructors

DaylightTimeZoneComponent({required DateTimeStartProperty dateTimeStart, required TimeZoneOffsetFromProperty timeZoneOffsetFrom, required TimeZoneOffsetToProperty timeZoneOffsetTo, List<CommentProperty>? comments, List<RecurrenceDateTimesProperty>? recurrenceDateTimes, List<RecurrenceRuleProperty>? recurrenceRules, List<TimeZoneNameProperty>? timeZoneNames})
const
DaylightTimeZoneComponent.fromCrawledBlock(CrawledBlock block)
factory

Properties

comments List<CommentProperty>?
finalinherited
componentName String
finalinherited
dateTimeStart DateTimeStartProperty
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
recurrenceDateTimes List<RecurrenceDateTimesProperty>?
finalinherited
recurrenceRules List<RecurrenceRuleProperty>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timeZoneNames List<TimeZoneNameProperty>?
finalinherited
timeZoneOffsetFrom TimeZoneOffsetFromProperty
finalinherited
timeZoneOffsetTo TimeZoneOffsetToProperty
finalinherited

Methods

getProperties() List<CalendarProperty<CalendarValue>>
inherited
getSubComponents() List<CalendarComponent>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited