DelegateesParameter class
RFC2445 Section 4.2.5
- Inheritance
-
- Object
- CalendarParameter<
CalendarParameterValueList< CalendarUserAddressParameterValue> > - DelegateesParameter
Constructors
-
DelegateesParameter(List<
String> emails) - DelegateesParameter.fromCrawledParameter(CrawledParameter parameter)
-
factory
Properties
-
emails
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parameterName → String
-
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
value
→ CalendarParameterValueList<
CalendarUserAddressParameterValue> -
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
testCrawledParameter(
CrawledParameter parameter) → bool