inWeeks property
Will produce a duration value that only accounts for the number of weeks.
Ex: Duration(days: 8, hours: 7, minutes: 2) == "P1W"
Implementation
final bool inWeeks;
Will produce a duration value that only accounts for the number of weeks.
Ex: Duration(days: 8, hours: 7, minutes: 2) == "P1W"
final bool inWeeks;