JournalComponent class

RFC2445 Section 4.6.3

Inheritance

Constructors

JournalComponent({ClassificationProperty? classification, DateTimeCreatedProperty? dateTimeCreated, DescriptionProperty? description, DateTimeStartProperty? dateTimeStart, DateTimeStampProperty? dateTimeStamp, LastModifiedProperty? lastModified, OrganizerProperty? organizer, RecurrenceIdProperty? recurrenceId, SequenceProperty? sequence, StatusProperty? status, SummaryProperty? summary, UniqueIdentifierProperty? uniqueIdentifier, URLProperty? url, List<UriAttachmentProperty>? uriAttachments, List<BinaryAttachmentProperty>? binaryAttachments, List<AttendeeProperty>? attendees, List<CategoriesProperty>? categories, List<CommentProperty>? comments, List<ContactProperty>? contacts, List<ExceptionDateTimesProperty>? exceptionDateTimes, List<ExceptionRuleProperty>? exceptionRules, List<RelatedToProperty>? relatedTo, List<RecurrenceDateTimesProperty>? recurrenceDateTimes, List<RecurrenceRuleProperty>? recurrenceRules, List<RequestStatusProperty>? requestStatuses})
const
JournalComponent.fromCrawledBlock(CrawledBlock block)
factory

Properties

attendees List<AttendeeProperty>?
final
binaryAttachments List<BinaryAttachmentProperty>?
final
categories List<CategoriesProperty>?
final
classification ClassificationProperty?
final
comments List<CommentProperty>?
final
componentName String
finalinherited
contacts List<ContactProperty>?
final
dateTimeCreated DateTimeCreatedProperty?
final
dateTimeStamp DateTimeStampProperty?
final
dateTimeStart DateTimeStartProperty?
final
description DescriptionProperty?
final
exceptionDateTimes List<ExceptionDateTimesProperty>?
final
exceptionRules List<ExceptionRuleProperty>?
final
hashCode int
The hash code for this object.
no setterinherited
lastModified LastModifiedProperty?
final
organizer OrganizerProperty?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
recurrenceDateTimes List<RecurrenceDateTimesProperty>?
final
recurrenceId RecurrenceIdProperty?
final
recurrenceRules List<RecurrenceRuleProperty>?
final
relatedTo List<RelatedToProperty>?
final
requestStatuses List<RequestStatusProperty>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence SequenceProperty?
final
status StatusProperty?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
summary SummaryProperty?
final
uniqueIdentifier UniqueIdentifierProperty?
final
uriAttachments List<UriAttachmentProperty>?
final
url URLProperty?
final

Methods

getProperties() List<CalendarProperty<CalendarValue>>
override
getSubComponents() List<CalendarComponent>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited