ProcedureAlarmComponent class

RFC2445 Section 4.6.6

Inheritance

Constructors

ProcedureAlarmComponent({DateTimeTriggerProperty? dateTimeTrigger, DurationTriggerProperty? durationTrigger, UriAttachmentProperty? uriAttachment, BinaryAttachmentProperty? binaryAttachment, DurationProperty? duration, RepeatCountProperty? repeatCount, DescriptionProperty? description})
const
ProcedureAlarmComponent.fromCrawledBlock(CrawledBlock block)
factory

Properties

binaryAttachment BinaryAttachmentProperty?
final
componentName String
finalinherited
dateTimeTrigger DateTimeTriggerProperty?
final
description DescriptionProperty?
final
duration DurationProperty?
final
durationTrigger DurationTriggerProperty?
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
repeatCount RepeatCountProperty?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uriAttachment UriAttachmentProperty?
final

Methods

getProperties() List<CalendarProperty<CalendarValue>>
override
getSubComponents() List<CalendarComponent>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited