RecurrenceRuleParameterValue class
- Inheritance
-
- Mixed-in types
-
Constructors
-
RecurrenceRuleParameterValue({required RecurrenceFrequency frequency, int interval = RecurrenceRule.defaultInterval, RecurrenceWeekday startOfWorkWeek = RecurrenceRule.defaultStartOfWorkWeek, DateTime? until, int? count, Set<int>? bySeconds, Set<int>? byMinutes, Set<int>? byHours, Set<RecurrenceByDay>? byDays, Set<int>? byMonthDays, Set<int>? byYearDays, Set<int>? byWeekNumbers, Set<int>? byMonths, Set<int>? bySetPositions})
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
type
→ ValueType
-
finalinherited
-
value
→ RecurrenceRule
-
finalinherited