RecurrenceRuleValue class
RFC2445 Section 4.3.10
- Inheritance
-
- Object
- CalendarValue<
RecurrenceRule> - CalendarMultiPartStructuredValue<
RecurrenceRule> - RecurrenceRuleValue
- Implementers
Constructors
-
RecurrenceRuleValue({required RecurrenceFrequency frequency, int interval = RecurrenceRule.defaultInterval, RecurrenceWeekday startOfWorkWeek = RecurrenceRule.defaultStartOfWorkWeek, DateTime? until, int? count, Set<
int> ? bySeconds, Set<int> ? byMinutes, Set<int> ? byHours, Set<RecurrenceByDay> ? byDays, Set<int> ? byMonthDays, Set<int> ? byYearDays, Set<int> ? byWeekNumbers, Set<int> ? byMonths, Set<int> ? bySetPositions}) - RecurrenceRuleValue.fromCrawledStringValue(String value, {String? timeZoneIdentifier})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → ValueType
-
finalinherited
- value → RecurrenceRule
-
finalinherited
Methods
-
getInlineParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
inherited
-
getValueParts(
) → List< CalendarStructuredValuePart> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitizeToString(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited