TodoComponent class

RFC2445 Section 4.6.2

Inheritance

Constructors

TodoComponent({ClassificationProperty? classification, DateTimeCompletedProperty? dateTimeCompleted, DateTimeCreatedProperty? dateTimeCreated, DescriptionProperty? description, DateTimeStampProperty? dateTimeStamp, DateTimeStartProperty? dateTimeStart, GeographicPositionProperty? geographicPosition, LastModifiedProperty? lastModified, LocationProperty? location, OrganizerProperty? organizer, PercentCompleteProperty? percentComplete, PriorityProperty? priority, RecurrenceIdProperty? recurrenceId, SequenceProperty? sequence, StatusProperty? status, SummaryProperty? summary, UniqueIdentifierProperty? uniqueIdentifier, URLProperty? url, DateTimeDueProperty? dateTimeDue, DurationProperty? duration, List<UriAttachmentProperty>? uriAttachments, List<BinaryAttachmentProperty>? binaryAttachments, List<AttendeeProperty>? attendees, List<CategoriesProperty>? categories, List<CommentProperty>? comments, List<ContactProperty>? contacts, List<ExceptionDateTimesProperty>? exceptionDateTimes, List<ExceptionRuleProperty>? exceptionRules, List<RequestStatusProperty>? requestStatuses, List<RelatedToProperty>? relatedTo, List<ResourcesProperty>? resources, List<RecurrenceDateTimesProperty>? recurrenceDateTimes, List<RecurrenceRuleProperty>? recurrenceRules, List<AudioAlarmComponent>? audioAlarms, List<DisplayAlarmComponent>? displayAlarms, List<EmailAlarmComponent>? emailAlarms, List<ProcedureAlarmComponent>? procedureAlarms})
const
TodoComponent.fromCrawledBlock(CrawledBlock block)
factory

Properties

attendees List<AttendeeProperty>?
final
audioAlarms List<AudioAlarmComponent>?
final
binaryAttachments List<BinaryAttachmentProperty>?
final
categories List<CategoriesProperty>?
final
classification ClassificationProperty?
final
comments List<CommentProperty>?
final
componentName String
finalinherited
contacts List<ContactProperty>?
final
dateTimeCompleted DateTimeCompletedProperty?
final
dateTimeCreated DateTimeCreatedProperty?
final
dateTimeDue DateTimeDueProperty?
final
dateTimeStamp DateTimeStampProperty?
final
dateTimeStart DateTimeStartProperty?
final
description DescriptionProperty?
final
displayAlarms List<DisplayAlarmComponent>?
final
duration DurationProperty?
final
emailAlarms List<EmailAlarmComponent>?
final
exceptionDateTimes List<ExceptionDateTimesProperty>?
final
exceptionRules List<ExceptionRuleProperty>?
final
geographicPosition GeographicPositionProperty?
final
hashCode int
The hash code for this object.
no setterinherited
lastModified LastModifiedProperty?
final
location LocationProperty?
final
organizer OrganizerProperty?
final
percentComplete PercentCompleteProperty?
final
priority PriorityProperty?
final
procedureAlarms List<ProcedureAlarmComponent>?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
recurrenceDateTimes List<RecurrenceDateTimesProperty>?
final
recurrenceId RecurrenceIdProperty?
final
recurrenceRules List<RecurrenceRuleProperty>?
final
relatedTo List<RelatedToProperty>?
final
requestStatuses List<RequestStatusProperty>?
final
resources List<ResourcesProperty>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence SequenceProperty?
final
status StatusProperty?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
summary SummaryProperty?
final
uniqueIdentifier UniqueIdentifierProperty?
final
uriAttachments List<UriAttachmentProperty>?
final
url URLProperty?
final

Methods

getProperties() List<CalendarProperty<CalendarValue>>
override
getSubComponents() List<CalendarComponent>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited