ValueType enum

Inheritance
Available extensions

Values

binary → const ValueType
boolean → const ValueType
calAddress → const ValueType
date → const ValueType
dateTime → const ValueType
duration → const ValueType
float → const ValueType
integer → const ValueType
period → const ValueType
recur → const ValueType
text → const ValueType
time → const ValueType
uri → const ValueType
utcOffset → const ValueType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on ValueType, provided by the CalendarValueStringRepresentation extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ValueType>
A constant List of the values in this enum, in order of their declaration.