CalendarValueList<T extends CalendarValue> class
- Inheritance
-
- Object
- CalendarValue<
List< T> > - CalendarValueList
- Implementers
Constructors
-
CalendarValueList(List<
T> values) - CalendarValueList.fromCrawledStringValue(String value, T toElement(String stringElement))
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
no setter
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → ValueType
-
finalinherited
-
value
→ List<
T> -
finalinherited
-
values
→ List<
T> -
final
Methods
-
getInlineParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitizeToString(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → T