FreeBusyComponent class
RFC2445 Section 4.6.4
- Inheritance
-
- Object
- CalendarComponent
- FreeBusyComponent
Constructors
-
FreeBusyComponent({ContactProperty? contact, DateTimeStartProperty? dateTimeStart, DateTimeEndProperty? dateTimeEnd, DurationProperty? duration, DateTimeStampProperty? dateTimeStamp, OrganizerProperty? organizer, UniqueIdentifierProperty? uniqueIdentifier, URLProperty? url, List<
AttendeeProperty> ? attendees, List<CommentProperty> ? comments, List<FreeBusyTimeProperty> ? freeBusyTimes, List<RequestStatusProperty> ? requestStatuses}) -
const
- FreeBusyComponent.fromCrawledBlock(CrawledBlock block)
-
factory
Properties
-
attendees
→ List<
AttendeeProperty> ? -
final
-
comments
→ List<
CommentProperty> ? -
final
- componentName → String
-
finalinherited
- contact → ContactProperty?
-
final
- dateTimeEnd → DateTimeEndProperty?
-
final
- dateTimeStamp → DateTimeStampProperty?
-
final
- dateTimeStart → DateTimeStartProperty?
-
final
- duration → DurationProperty?
-
final
-
freeBusyTimes
→ List<
FreeBusyTimeProperty> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizer → OrganizerProperty?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
-
requestStatuses
→ List<
RequestStatusProperty> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - uniqueIdentifier → UniqueIdentifierProperty?
-
final
- url → URLProperty?
-
final
Methods
-
getProperties(
) → List< CalendarProperty< CalendarValue> > -
override
-
getSubComponents(
) → List< CalendarComponent> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited