PeriodOfTimeParameterValue class
- Inheritance
-
- Object
- CalendarValue<
PeriodOfTime> - PeriodOfTimeValue
- PeriodOfTimeParameterValue
- Mixed-in types
Constructors
Properties
- duration → Duration?
-
finalinherited
- durationInWeeks → bool
-
Will produce a duration value that only
accounts for the number of weeks.
(Only relevant if supplying duration)
finalinherited
- end → DateTime?
-
finalinherited
- fixed → bool
-
If set to
true, will fix the time value to either the supplied timeZoneIdentifier or to theUTCtimezone by defaultfinalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timeZoneIdentifier → String?
-
The
tzIdvalue of a TimeZoneComponent located inside the current calendarfinalinherited - type → ValueType
-
finalinherited
- value → PeriodOfTime
-
finalinherited
Methods
-
getInlineParameters(
) → List< CalendarParameter< CalendarParameterValue> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitizeToString(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited