TimeZoneComponent class
RFC2445 Section 4.6.5
- Inheritance
-
- Object
- CalendarComponent
- TimeZoneComponent
Constructors
-
TimeZoneComponent({required TimeZoneIdentifierProperty timeZoneIdentifier, LastModifiedProperty? lastModified, TimeZoneUrlProperty? timeZoneUrl, List<
StandardTimeZoneComponent> ? standardTimeZones, List<DaylightTimeZoneComponent> ? daylightTimeZones}) -
const
- TimeZoneComponent.fromCrawledBlock(CrawledBlock block)
-
factory
Properties
- componentName → String
-
finalinherited
-
daylightTimeZones
→ List<
DaylightTimeZoneComponent> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → LastModifiedProperty?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
standardTimeZones
→ List<
StandardTimeZoneComponent> ? -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - timeZoneIdentifier → TimeZoneIdentifierProperty
-
final
- timeZoneUrl → TimeZoneUrlProperty?
-
final
Methods
-
getProperties(
) → List< CalendarProperty< CalendarValue> > -
override
-
getSubComponents(
) → List< CalendarComponent> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited